@@ -536,7 +536,7 @@ class Maybe(BaseDeclaration):
             return target
 
     def evaluate_pre(self, instance, step, overrides):
-        choice = self.decider.evaluate(instance=instance, step=step, extra={})
+        choice = self.decider.evaluate_pre(instance=instance, step=step, overrides={})
         target = self.yes if choice else self.no
         # The value can't be POST_INSTANTIATION, checked in __init__;
         # evaluate it as `evaluate_pre`
@@ -657,7 +657,7 @@ class PostGenerationDeclaration(BaseDeclaration):
         Args:
             instance (object): the newly generated object
             step (bool): whether the object was 'built' or 'created'
-            context: a builder.PostGenerationContext containing values
+            context: a declarations.PostGenerationContext containing values
                 extracted from the containing factory's declaration
         """
         raise NotImplementedError()
